@@ -1,10 +1,15 @@
 from .proto_structures import Comment
-from .constant import Constant
+from .constant import (
+    SLASH_STAR,
+    STAR_SLASH,
+    DOUBLE_SLASH,
+    STAR
+)
 from .proto_structures import Position
 from .util import remove_prefix, remove_suffix
 
 
-class CommentParser(Constant):
+class CommentParser:
     def __init__(self):
         self.end_line = 0
 
@@ -21,7 +26,7 @@ class CommentParser(Constant):
                 continue
 
             if self._start_with_multiple_line_comment(line):
-                self.multiple_comment_start_symbol_stack.append(self.SLASH_STAR)
+                self.multiple_comment_start_symbol_stack.append(SLASH_STAR)
                 comment_lines.append(line)
                 continue
 
@@ -29,7 +34,7 @@ class CommentParser(Constant):
                 comment_lines.append(line)
 
             if self._end_with_multiple_line_comment(line):
-                self.multiple_comment_end_symbol_stack.append(self.STAR_SLASH)
+                self.multiple_comment_end_symbol_stack.append(STAR_SLASH)
                 continue
 
             if line and not self.is_comment(line):
@@ -43,44 +48,47 @@ class CommentParser(Constant):
         return variable != '\n'
 
     def parse(self, comment_lines):
-        comment_lines = self.remove_prefix_symble(comment_lines)
+        comment_lines = self.remove_prefix_symbol(comment_lines)
 
         comment_lines = list(filter(None, comment_lines))
         comment_lines = list(filter(self.is_not_new_line, comment_lines))
 
         return comment_lines
 
-    def remove_prefix_symble(self, comment_lines):
+    def remove_prefix_symbol(self, comment_lines):
         processed_lines = []
         for line in comment_lines:
-            if line.strip().startswith(self.DOUBLE_SLASH):
-                # remove the single comment symble if have, E.g. // I'am a comment
+            if line.strip().startswith(DOUBLE_SLASH):
+                # remove the single comment symbol if have, E.g. // I'am a comment
                 processed_lines.append(line.strip()[2:].strip())
             elif self._start_with_multiple_line_comment(line) or self._end_with_multiple_line_comment(line):
-                # remove the multiple comment symble if have, E.g. /* I'am a comment */
-                processed_lines.append(line.strip().replace(self.SLASH_STAR, "").replace(self.STAR_SLASH, ''))
-            elif (line.strip().startswith(self.STAR) or line.strip().startswith(
-                    self.STAR * 2)) and not self._end_with_multiple_line_comment(line):
-                # remove the multiple comment symble if have, E.g. * I'am a comment in multiple line comment
+                # remove the multiple comment symbol if have, E.g. /* I'am a comment */
+                processed_lines.append(line.strip().replace(SLASH_STAR, "").replace(STAR_SLASH, ''))
+            elif (line.strip().startswith(STAR) or line.strip().startswith(
+                    STAR * 2)) and not self._end_with_multiple_line_comment(line):
+                # remove the multiple comment symbol if have, E.g. * I'am a comment in multiple line comment
                 # Example:
                 # /*
                 # **    Device information, including user agent, device proto_type and ip address.
                 # */
                 #
-                processed_lines.append(line.strip().replace(self.STAR, ""))
+                processed_lines.append(line.strip().replace(STAR, ""))
             else:
                 processed_lines.append(line.strip())
 
         return processed_lines
 
-    def _start_with_single_line_comment(self, line):
-        return line.strip().startswith(self.DOUBLE_SLASH)
+    @staticmethod
+    def _start_with_single_line_comment(line):
+        return line.strip().startswith(DOUBLE_SLASH)
 
-    def _start_with_multiple_line_comment(self, line):
-        return line.strip().startswith(self.SLASH_STAR)
+    @staticmethod
+    def _start_with_multiple_line_comment(line):
+        return line.strip().startswith(SLASH_STAR)
 
-    def _end_with_multiple_line_comment(self, line):
-        return line.strip().endswith(self.STAR_SLASH)
+    @staticmethod
+    def _end_with_multiple_line_comment(line):
+        return line.strip().endswith(STAR_SLASH)
 
     def _is_multiple_comment(self):
         if len(self.multiple_comment_start_symbol_stack) == 0:
@@ -100,24 +108,32 @@ class CommentParser(Constant):
     @staticmethod
     def parse_single_line_comment(line):
         comment = None
-        if line.count(CommentParser.DOUBLE_SLASH) > 0:
-            start_index = line.index(CommentParser.DOUBLE_SLASH)
-            comment_str = line[start_index:].lstrip(CommentParser.DOUBLE_SLASH).strip()
+        if line.count(DOUBLE_SLASH) > 0:
+            start_index = line.index(DOUBLE_SLASH)
+            comment_str = line[start_index:].lstrip(DOUBLE_SLASH).strip()
             comment = Comment(comment_str, Position.Right)
         return comment
 
     @staticmethod
     def create_top_comments(comments):
+        return CommentParser.create_comment_with_position(comments, Position.TOP)
+
+    @staticmethod
+    def create_bottom_comments(comments):
+        return CommentParser.create_comment_with_position(comments, Position.BOTTOM)
+
+    @staticmethod
+    def create_comment_with_position(comments, position: Position):
         result = []
         while comments:
             comment_lines = comments.pop(0)
             text = ''.join(comment_lines)
             text = text.strip()
-            text = remove_prefix(text, CommentParser.DOUBLE_SLASH)
-            text = remove_prefix(text, CommentParser.SLASH_STAR)
-            text = remove_suffix(text, CommentParser.STAR_SLASH)
+            text = remove_prefix(text, DOUBLE_SLASH)
+            text = remove_prefix(text, SLASH_STAR)
+            text = remove_suffix(text, STAR_SLASH)
             text = text.strip()
-            result.append(Comment(text, Position.TOP))
+            result.append(Comment(text, position))
         return result
 
     @staticmethod
