@@ -152,6 +152,12 @@ def main():
         default=os.getcwd(),
         help="target directory, default is current directory, all protobuf files under it including all subdirectories will be formatted."
     )
+    format_parser.add_argument(
+        "--preview",
+        type=str,
+        default=os.getcwd(),
+        help="preview formatted protobuf file with syntax highlighting."
+    )
     format_parser.add_argument(
         "--indents",
         type=int,
