@@ -1,8 +1,16 @@
 import uuid
 from attrdict import AttrDict
-from .detector import Detector
+from .type_detector import ProtoTypeDetector
 from .comment import CommentParser
-from .constant import Constant
+from .constant import (
+    RIGHT_BRACE,
+    EQUAL_SIGN,
+    LEFT_BRACE,
+    SEMICOLON,
+    RIGHT_ANGLE_BRACKET,
+    LEFT_SQUARE_BRACKET,
+    RIGHT_SQUARE_BRACKET
+)
 from .proto_structures import EnumElement
 from .proto_structures import Extend
 from .proto_structures import ExtendElement
@@ -15,9 +23,10 @@ from .proto_structures import Oneof
 from .protobuf import Protobuf
 
 
-class ObjectParser(Constant):
+class ObjectParser(CommentParser):
 
     def __init__(self):
+        super().__init__()
         self.objects = []
         self.objects_dict = {}
 
@@ -43,18 +52,22 @@ class ObjectParser(Constant):
         proto_obj.objects.append(self.obj)
 
     def parse(self, lines):
-        top_comments = Detector().get_top_comments(lines)
+        top_comments = ProtoTypeDetector().get_top_comments(lines)
         if len(lines) == 0:
+            if top_comments:
+                comments = self.create_bottom_comments(top_comments)
+                # add it to the comments of last one object
+                self.current_obj.comments.extend(comments)
             return
 
         first_line = lines[0]
-        if Detector().is_object_start(first_line):
-            self.left_brace_stack.append(self.LEFT_BRACE)
+        if ProtoTypeDetector().is_object_start(first_line):
+            self.left_brace_stack.append(LEFT_BRACE)
 
-        proto_type = Detector().get_type(first_line)
+        proto_type = ProtoTypeDetector().get_type(first_line)
         if 'message' == proto_type or 'enum' == proto_type or 'service' == proto_type or 'extend' == proto_type or 'oneof' == proto_type:
             name = self._get_obj_name(first_line)
-            top_comments = CommentParser.create_comment(first_line, top_comments)
+            top_comments = self.create_comment(first_line, top_comments)
             obj = self.create_proto_obj(proto_type, name, top_comments)
             self.objects_dict[obj.id] = obj
 
@@ -75,11 +88,15 @@ class ObjectParser(Constant):
             lines.pop(0)
             return self.parse(lines)
         else:
-            if Detector().is_object_end(first_line):
-                self.right_brace_stack.append(self.RIGHT_BRACE)
+            if ProtoTypeDetector().is_object_end(first_line):
+                self.right_brace_stack.append(RIGHT_BRACE)
+                if top_comments:
+                    comments = self.create_bottom_comments(top_comments)
+                    # add it to the comments of last one element
+                    self.current_obj.elements[-1].comments.extend(comments)
                 if self.current_obj.parent_id is None:  # root node, finish a root level object parse
                     self.objects.append(self.current_obj)
-                    self.obj = None  # finshed a object and all netested inner objects(if has) parse.
+                    self.obj = None  # finished an object and all nested inner objects(if it has) parse.
                 else:
                     self.current_obj = self.objects_dict[self.current_obj.parent_id]
 
@@ -122,15 +139,15 @@ class ObjectParser(Constant):
         if top_comments is None:
             top_comments = []
         line = line.strip()
-        equal_sign_index = line.index(cls.EQUAL_SIGN)
-        semicolon_index = line.index(cls.SEMICOLON)
+        equal_sign_index = line.index(EQUAL_SIGN)
+        semicolon_index = line.index(SEMICOLON)
         str_before_equqal_sign = line[:equal_sign_index]
         parts = str_before_equqal_sign.split(' ')
         parts = list(filter(None, parts))
         value = line[equal_sign_index + 1:semicolon_index].strip()
         data = cls.get_number_and_annotation(value)
 
-        comments = CommentParser.create_comment(line, top_comments)
+        comments = cls.create_comment(line, top_comments)
         return EnumElement(name=parts[0], number=data.number, annotation=data.annotation, comments=comments)
 
     @classmethod
@@ -145,15 +162,15 @@ class ObjectParser(Constant):
             return cls.make_map_element(line, top_comments)
 
         line = line.strip()
-        equal_sign_index = line.index(cls.EQUAL_SIGN)
-        semicolon_index = line.index(cls.SEMICOLON)
+        equal_sign_index = line.index(EQUAL_SIGN)
+        semicolon_index = line.index(SEMICOLON)
         str_before_equqal_sign = line[:equal_sign_index]
         parts = str_before_equqal_sign.split(' ')
         parts = list(filter(None, parts))
         value = line[equal_sign_index + 1:semicolon_index].strip()
         data = cls.get_number_and_annotation(value)
 
-        comments = CommentParser.create_comment(line, top_comments)
+        comments = cls.create_comment(line, top_comments)
         if len(parts) == 2:
             return MessageElement(type=parts[0], name=parts[1], number=data.number, annotation=data.annotation,
                                   comments=comments)
@@ -168,15 +185,15 @@ class ObjectParser(Constant):
     def parse_extend_element(cls, line, top_comments=None):
         # common.RequestContext  request_context = 1;
         line = line.strip()
-        equal_sign_index = line.index(cls.EQUAL_SIGN)
-        semicolon_index = line.index(cls.SEMICOLON)
+        equal_sign_index = line.index(EQUAL_SIGN)
+        semicolon_index = line.index(SEMICOLON)
         str_before_equqal_sign = line[:equal_sign_index]
         parts = str_before_equqal_sign.split(' ')
         parts = list(filter(None, parts))
         value = line[equal_sign_index + 1:semicolon_index].strip()
         data = cls.get_number_and_annotation(value)
 
-        comments = CommentParser.create_comment(line, top_comments)
+        comments = cls.create_comment(line, top_comments)
         if len(parts) == 2:
             return ExtendElement(type=parts[0], name=parts[1], number=data.number, annotation=data.annotation,
                                  comments=comments)
@@ -192,9 +209,9 @@ class ObjectParser(Constant):
         # map<string, Project> projects = 3;
         if top_comments is None:
             top_comments = []
-        right_bracket_index = line.index(cls.RIGHT_ANGLE_BRACKET)
-        equal_sign_index = line.index(cls.EQUAL_SIGN)
-        semicolon_index = line.index(cls.SEMICOLON)
+        right_bracket_index = line.index(RIGHT_ANGLE_BRACKET)
+        equal_sign_index = line.index(EQUAL_SIGN)
+        semicolon_index = line.index(SEMICOLON)
         map_type = line[:right_bracket_index + 1]
         map_type = map_type.strip().replace(' ', '')
         type_parts = map_type.split(',')
@@ -203,7 +220,7 @@ class ObjectParser(Constant):
         name = name.strip()
         number = line[equal_sign_index + 1:semicolon_index]
         number = number.strip()
-        comments = CommentParser.create_comment(line, top_comments)
+        comments = cls.create_comment(line, top_comments)
 
         return MessageElement(type=map_type, name=name, number=number, comments=comments)
 
@@ -215,11 +232,11 @@ class ObjectParser(Constant):
         line = line.strip().replace('(', '')
         line = line.replace(')', '')
 
-        semicolon_index = line.index(cls.SEMICOLON)
+        semicolon_index = line.index(SEMICOLON)
         str_before_semicolon = line[:semicolon_index]
         parts = str_before_semicolon.split(' ')
         parts = list(filter(None, parts))
-        comments = CommentParser.create_comment(line, top_comments)
+        comments = cls.create_comment(line, top_comments)
 
         return ServiceElement(label=parts[0], name=parts[1], request=parts[2], response=parts[4], comments=comments)
 
@@ -227,9 +244,9 @@ class ObjectParser(Constant):
     def get_number_and_annotation(cls, value):
         number = value
         annotation = ''
-        if cls.LEFT_SQUARE_BRACKET in value:
-            left_brace_stack_index = value.index(cls.LEFT_SQUARE_BRACKET)
-            right_brace_stack_index = value.rindex(cls.RIGHT_SQUARE_BRACKET)
+        if LEFT_SQUARE_BRACKET in value:
+            left_brace_stack_index = value.index(LEFT_SQUARE_BRACKET)
+            right_brace_stack_index = value.rindex(RIGHT_SQUARE_BRACKET)
             annotation = value[left_brace_stack_index:right_brace_stack_index + 1]
             annotation = annotation.strip()
             number = value[:left_brace_stack_index]
